# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'ProviderAssumeRoleArgs',
    'ProviderAssumeRoleArgsDict',
    'ProviderAssumeRoleWithOidcArgs',
    'ProviderAssumeRoleWithOidcArgsDict',
    'ProviderEndpointArgs',
    'ProviderEndpointArgsDict',
    'ProviderSignVersionArgs',
    'ProviderSignVersionArgsDict',
]

MYPY = False

if not MYPY:
    class ProviderAssumeRoleArgsDict(TypedDict):
        role_arn: pulumi.Input[str]
        """
        The ARN of a RAM role to assume prior to making API calls.
        """
        external_id: NotRequired[pulumi.Input[str]]
        policy: NotRequired[pulumi.Input[str]]
        """
        The permissions applied when assuming a role. You cannot use, this policy to grant further permissions that are in excess to those of the, role that is being assumed.
        """
        session_expiration: NotRequired[pulumi.Input[int]]
        """
        The time after which the established session for assuming role expires. Valid value range: [900-3600] seconds. Default to 0 (in this case Alicloud use own default value).
        """
        session_name: NotRequired[pulumi.Input[str]]
elif False:
    ProviderAssumeRoleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ProviderAssumeRoleArgs:
    def __init__(__self__, *,
                 role_arn: pulumi.Input[str],
                 external_id: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 session_expiration: Optional[pulumi.Input[int]] = None,
                 session_name: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] role_arn: The ARN of a RAM role to assume prior to making API calls.
        :param pulumi.Input[str] policy: The permissions applied when assuming a role. You cannot use, this policy to grant further permissions that are in excess to those of the, role that is being assumed.
        :param pulumi.Input[int] session_expiration: The time after which the established session for assuming role expires. Valid value range: [900-3600] seconds. Default to 0 (in this case Alicloud use own default value).
        """
        pulumi.set(__self__, "role_arn", role_arn)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if session_expiration is not None:
            pulumi.set(__self__, "session_expiration", session_expiration)
        if session_name is not None:
            pulumi.set(__self__, "session_name", session_name)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Input[str]:
        """
        The ARN of a RAM role to assume prior to making API calls.
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        The permissions applied when assuming a role. You cannot use, this policy to grant further permissions that are in excess to those of the, role that is being assumed.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="sessionExpiration")
    def session_expiration(self) -> Optional[pulumi.Input[int]]:
        """
        The time after which the established session for assuming role expires. Valid value range: [900-3600] seconds. Default to 0 (in this case Alicloud use own default value).
        """
        return pulumi.get(self, "session_expiration")

    @session_expiration.setter
    def session_expiration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "session_expiration", value)

    @property
    @pulumi.getter(name="sessionName")
    def session_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "session_name")

    @session_name.setter
    def session_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "session_name", value)


if not MYPY:
    class ProviderAssumeRoleWithOidcArgsDict(TypedDict):
        oidc_provider_arn: pulumi.Input[str]
        """
        ARN of the OIDC IdP.
        """
        role_arn: pulumi.Input[str]
        """
        ARN of a RAM role to assume prior to making API calls.
        """
        oidc_token: NotRequired[pulumi.Input[str]]
        oidc_token_file: NotRequired[pulumi.Input[str]]
        """
        The file path of OIDC token that is issued by the external IdP.
        """
        policy: NotRequired[pulumi.Input[str]]
        """
        The policy that specifies the permissions of the returned STS token. You can use this parameter to grant the STS token fewer permissions than the permissions granted to the RAM role.
        """
        role_session_name: NotRequired[pulumi.Input[str]]
        """
        The custom name of the role session. Set this parameter based on your business requirements. In most cases, this parameter is set to the identity of the user who calls the operation, for example, the username.
        """
        session_expiration: NotRequired[pulumi.Input[int]]
        """
        The validity period of the STS token. Unit: seconds. Default value: 3600. Minimum value: 900. Maximum value: the value of the MaxSessionDuration parameter when creating a ram role.
        """
elif False:
    ProviderAssumeRoleWithOidcArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ProviderAssumeRoleWithOidcArgs:
    def __init__(__self__, *,
                 oidc_provider_arn: pulumi.Input[str],
                 role_arn: pulumi.Input[str],
                 oidc_token: Optional[pulumi.Input[str]] = None,
                 oidc_token_file: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 role_session_name: Optional[pulumi.Input[str]] = None,
                 session_expiration: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] oidc_provider_arn: ARN of the OIDC IdP.
        :param pulumi.Input[str] role_arn: ARN of a RAM role to assume prior to making API calls.
        :param pulumi.Input[str] oidc_token_file: The file path of OIDC token that is issued by the external IdP.
        :param pulumi.Input[str] policy: The policy that specifies the permissions of the returned STS token. You can use this parameter to grant the STS token fewer permissions than the permissions granted to the RAM role.
        :param pulumi.Input[str] role_session_name: The custom name of the role session. Set this parameter based on your business requirements. In most cases, this parameter is set to the identity of the user who calls the operation, for example, the username.
        :param pulumi.Input[int] session_expiration: The validity period of the STS token. Unit: seconds. Default value: 3600. Minimum value: 900. Maximum value: the value of the MaxSessionDuration parameter when creating a ram role.
        """
        pulumi.set(__self__, "oidc_provider_arn", oidc_provider_arn)
        pulumi.set(__self__, "role_arn", role_arn)
        if oidc_token is not None:
            pulumi.set(__self__, "oidc_token", oidc_token)
        if oidc_token_file is not None:
            pulumi.set(__self__, "oidc_token_file", oidc_token_file)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if role_session_name is not None:
            pulumi.set(__self__, "role_session_name", role_session_name)
        if session_expiration is not None:
            pulumi.set(__self__, "session_expiration", session_expiration)

    @property
    @pulumi.getter(name="oidcProviderArn")
    def oidc_provider_arn(self) -> pulumi.Input[str]:
        """
        ARN of the OIDC IdP.
        """
        return pulumi.get(self, "oidc_provider_arn")

    @oidc_provider_arn.setter
    def oidc_provider_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "oidc_provider_arn", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Input[str]:
        """
        ARN of a RAM role to assume prior to making API calls.
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter(name="oidcToken")
    def oidc_token(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "oidc_token")

    @oidc_token.setter
    def oidc_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_token", value)

    @property
    @pulumi.getter(name="oidcTokenFile")
    def oidc_token_file(self) -> Optional[pulumi.Input[str]]:
        """
        The file path of OIDC token that is issued by the external IdP.
        """
        return pulumi.get(self, "oidc_token_file")

    @oidc_token_file.setter
    def oidc_token_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oidc_token_file", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        The policy that specifies the permissions of the returned STS token. You can use this parameter to grant the STS token fewer permissions than the permissions granted to the RAM role.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="roleSessionName")
    def role_session_name(self) -> Optional[pulumi.Input[str]]:
        """
        The custom name of the role session. Set this parameter based on your business requirements. In most cases, this parameter is set to the identity of the user who calls the operation, for example, the username.
        """
        return pulumi.get(self, "role_session_name")

    @role_session_name.setter
    def role_session_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_session_name", value)

    @property
    @pulumi.getter(name="sessionExpiration")
    def session_expiration(self) -> Optional[pulumi.Input[int]]:
        """
        The validity period of the STS token. Unit: seconds. Default value: 3600. Minimum value: 900. Maximum value: the value of the MaxSessionDuration parameter when creating a ram role.
        """
        return pulumi.get(self, "session_expiration")

    @session_expiration.setter
    def session_expiration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "session_expiration", value)


if not MYPY:
    class ProviderEndpointArgsDict(TypedDict):
        acr: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom acr endpoints.
        """
        actiontrail: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Actiontrail endpoints.
        """
        adb: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom AnalyticDB endpoints.
        """
        alb: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom alb endpoints.
        """
        alidfs: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom alidfs endpoints.
        """
        alidns: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom alidns endpoints.
        """
        alikafka: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ALIKAFKA endpoints.
        """
        apigateway: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Api Gateway endpoints.
        """
        arms: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom arms endpoints.
        """
        bastionhost: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom bastionhost endpoints.
        """
        beebot: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom beebot endpoints.
        """
        bpstudio: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom bpstudio endpoints.
        """
        brain_industrial: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom brain_industrial endpoints.
        """
        bssopenapi: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom BSSOPENAPI endpoints.
        """
        cas: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom CAS endpoints.
        """
        cassandra: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cassandra endpoints.
        """
        cbn: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cbn endpoints.
        """
        cbs: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cbs endpoints.
        """
        cddc: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cddc endpoints.
        """
        cdn: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom CDN endpoints.
        """
        cds: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cds endpoints.
        """
        clickhouse: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom clickhouse endpoints.
        """
        cloudauth: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudauth endpoints.
        """
        cloudfirewall: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudfirewall endpoints.
        """
        cloudfw: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudfw endpoints.
        """
        cloudphone: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudphone endpoints.
        """
        cloudsso: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudsso endpoints.
        """
        cms: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Cloud Monitor endpoints.
        """
        computenest: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom computenest endpoints.
        """
        config: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom config endpoints.
        """
        cr: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Container Registry endpoints.
        """
        cs: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Container Service endpoints.
        """
        das: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom das endpoints.
        """
        datahub: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Datahub endpoints.
        """
        dataworkspublic: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dataworkspublic endpoints.
        """
        dbfs: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dbfs endpoints.
        """
        dcdn: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dcdn endpoints.
        """
        ddosbasic: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ddosbasic endpoints.
        """
        ddosbgp: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DDOSBGP endpoints.
        """
        ddoscoo: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DDOSCOO endpoints.
        """
        dds: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom MongoDB endpoints.
        """
        devopsrdc: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom devopsrdc endpoints.
        """
        dg: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dg endpoints.
        """
        dm: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dm endpoints.
        """
        dms_enterprise: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dms_enterprise endpoints.
        """
        dmsenterprise: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dmsenterprise endpoints.
        """
        dns: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DNS endpoints.
        """
        drds: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DRDS endpoints.
        """
        dts: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dts endpoints.
        """
        dysms: NotRequired[pulumi.Input[str]]
        eais: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eais endpoints.
        """
        ebs: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ebs endpoints.
        """
        eci: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eci endpoints.
        """
        ecs: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ECS endpoints.
        """
        edas: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom edas endpoints.
        """
        edasschedulerx: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom edasschedulerx endpoints.
        """
        edsuser: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom edsuser endpoints.
        """
        eflo: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eflo endpoints.
        """
        ehpc: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ehpc endpoints.
        """
        ehs: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ehs endpoints.
        """
        eipanycast: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eipanycast endpoints.
        """
        elasticsearch: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Elasticsearch endpoints.
        """
        emr: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom EMR endpoints.
        """
        ens: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ens endpoints.
        """
        ess: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Autoscaling endpoints.
        """
        eventbridge: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eventbridge_share endpoints.
        """
        fc: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Function Computing endpoints.
        """
        fnf: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom fnf endpoints.
        """
        ga: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ga endpoints.
        """
        gaplus: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom gaplus endpoints.
        """
        gds: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom gds endpoints.
        """
        gpdb: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom GPDB endpoints.
        """
        gwsecd: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom gwsecd endpoints.
        """
        hbr: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom hbr endpoints.
        """
        hcs_sgw: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom hcs_sgw endpoints.
        """
        hitsdb: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom hitsdb endpoints.
        """
        imm: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom imm endpoints.
        """
        imp: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom imp endpoints.
        """
        ims: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ims endpoints.
        """
        iot: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom iot endpoints.
        """
        kms: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom KMS endpoints.
        """
        kvstore: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom R-KVStore endpoints.
        """
        location: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Location Service endpoints.
        """
        log: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Log Service endpoints.
        """
        market: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Market Place endpoints.
        """
        maxcompute: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom MaxCompute endpoints.
        """
        mhub: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom mhub endpoints.
        """
        mns: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom MNS endpoints.
        """
        mscopensubscription: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom mscopensubscription endpoints.
        """
        mse: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom mse endpoints.
        """
        nas: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom NAS endpoints.
        """
        nlb: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom nlb endpoints.
        """
        oceanbase: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom oceanbase endpoints.
        """
        ons: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ONS endpoints.
        """
        onsproxy: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom onsproxy endpoints.
        """
        oos: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom oos endpoints.
        """
        opensearch: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom opensearch endpoints.
        """
        oss: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom OSS endpoints.
        """
        ots: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Table Store endpoints.
        """
        polardb: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom PolarDB endpoints.
        """
        privatelink: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom privatelink endpoints.
        """
        pvtz: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Private Zone endpoints.
        """
        quickbi: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom quickbi endpoints.
        """
        quotas: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom quotas endpoints.
        """
        r_kvstore: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom r_kvstore endpoints.
        """
        ram: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom RAM endpoints.
        """
        rds: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom RDS endpoints.
        """
        redisa: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom redisa endpoints.
        """
        resourcemanager: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom resourcemanager endpoints.
        """
        ressharing: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom resourcesharing endpoints.
        """
        ros: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ros endpoints.
        """
        sas: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom sas endpoints.
        """
        scdn: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom scdn endpoints.
        """
        sddp: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom sddp endpoints.
        """
        selectdb: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom selectdb endpoints.
        """
        serverless: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom serverless endpoints.
        """
        servicemesh: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom servicemesh endpoints.
        """
        sgw: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom sgw endpoints.
        """
        slb: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom SLB endpoints.
        """
        smartag: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom smartag endpoints.
        """
        srvcatalog: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom srvcatalog endpoints.
        """
        sts: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom STS endpoints.
        """
        swas: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom swas endpoints.
        """
        tag: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom tag endpoints.
        """
        vod: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom vod endpoints.
        """
        vpc: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom VPC and VPN endpoints.
        """
        vpcpeer: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom vpcpeer endpoints.
        """
        vs: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom vs endpoints.
        """
        waf: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom waf endpoints.
        """
        waf_openapi: NotRequired[pulumi.Input[str]]
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom waf_openapi endpoints.
        """
elif False:
    ProviderEndpointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ProviderEndpointArgs:
    def __init__(__self__, *,
                 acr: Optional[pulumi.Input[str]] = None,
                 actiontrail: Optional[pulumi.Input[str]] = None,
                 adb: Optional[pulumi.Input[str]] = None,
                 alb: Optional[pulumi.Input[str]] = None,
                 alidfs: Optional[pulumi.Input[str]] = None,
                 alidns: Optional[pulumi.Input[str]] = None,
                 alikafka: Optional[pulumi.Input[str]] = None,
                 apigateway: Optional[pulumi.Input[str]] = None,
                 arms: Optional[pulumi.Input[str]] = None,
                 bastionhost: Optional[pulumi.Input[str]] = None,
                 beebot: Optional[pulumi.Input[str]] = None,
                 bpstudio: Optional[pulumi.Input[str]] = None,
                 brain_industrial: Optional[pulumi.Input[str]] = None,
                 bssopenapi: Optional[pulumi.Input[str]] = None,
                 cas: Optional[pulumi.Input[str]] = None,
                 cassandra: Optional[pulumi.Input[str]] = None,
                 cbn: Optional[pulumi.Input[str]] = None,
                 cbs: Optional[pulumi.Input[str]] = None,
                 cddc: Optional[pulumi.Input[str]] = None,
                 cdn: Optional[pulumi.Input[str]] = None,
                 cds: Optional[pulumi.Input[str]] = None,
                 clickhouse: Optional[pulumi.Input[str]] = None,
                 cloudauth: Optional[pulumi.Input[str]] = None,
                 cloudfirewall: Optional[pulumi.Input[str]] = None,
                 cloudfw: Optional[pulumi.Input[str]] = None,
                 cloudphone: Optional[pulumi.Input[str]] = None,
                 cloudsso: Optional[pulumi.Input[str]] = None,
                 cms: Optional[pulumi.Input[str]] = None,
                 computenest: Optional[pulumi.Input[str]] = None,
                 config: Optional[pulumi.Input[str]] = None,
                 cr: Optional[pulumi.Input[str]] = None,
                 cs: Optional[pulumi.Input[str]] = None,
                 das: Optional[pulumi.Input[str]] = None,
                 datahub: Optional[pulumi.Input[str]] = None,
                 dataworkspublic: Optional[pulumi.Input[str]] = None,
                 dbfs: Optional[pulumi.Input[str]] = None,
                 dcdn: Optional[pulumi.Input[str]] = None,
                 ddosbasic: Optional[pulumi.Input[str]] = None,
                 ddosbgp: Optional[pulumi.Input[str]] = None,
                 ddoscoo: Optional[pulumi.Input[str]] = None,
                 dds: Optional[pulumi.Input[str]] = None,
                 devopsrdc: Optional[pulumi.Input[str]] = None,
                 dg: Optional[pulumi.Input[str]] = None,
                 dm: Optional[pulumi.Input[str]] = None,
                 dms_enterprise: Optional[pulumi.Input[str]] = None,
                 dmsenterprise: Optional[pulumi.Input[str]] = None,
                 dns: Optional[pulumi.Input[str]] = None,
                 drds: Optional[pulumi.Input[str]] = None,
                 dts: Optional[pulumi.Input[str]] = None,
                 dysms: Optional[pulumi.Input[str]] = None,
                 eais: Optional[pulumi.Input[str]] = None,
                 ebs: Optional[pulumi.Input[str]] = None,
                 eci: Optional[pulumi.Input[str]] = None,
                 ecs: Optional[pulumi.Input[str]] = None,
                 edas: Optional[pulumi.Input[str]] = None,
                 edasschedulerx: Optional[pulumi.Input[str]] = None,
                 edsuser: Optional[pulumi.Input[str]] = None,
                 eflo: Optional[pulumi.Input[str]] = None,
                 ehpc: Optional[pulumi.Input[str]] = None,
                 ehs: Optional[pulumi.Input[str]] = None,
                 eipanycast: Optional[pulumi.Input[str]] = None,
                 elasticsearch: Optional[pulumi.Input[str]] = None,
                 emr: Optional[pulumi.Input[str]] = None,
                 ens: Optional[pulumi.Input[str]] = None,
                 ess: Optional[pulumi.Input[str]] = None,
                 eventbridge: Optional[pulumi.Input[str]] = None,
                 fc: Optional[pulumi.Input[str]] = None,
                 fnf: Optional[pulumi.Input[str]] = None,
                 ga: Optional[pulumi.Input[str]] = None,
                 gaplus: Optional[pulumi.Input[str]] = None,
                 gds: Optional[pulumi.Input[str]] = None,
                 gpdb: Optional[pulumi.Input[str]] = None,
                 gwsecd: Optional[pulumi.Input[str]] = None,
                 hbr: Optional[pulumi.Input[str]] = None,
                 hcs_sgw: Optional[pulumi.Input[str]] = None,
                 hitsdb: Optional[pulumi.Input[str]] = None,
                 imm: Optional[pulumi.Input[str]] = None,
                 imp: Optional[pulumi.Input[str]] = None,
                 ims: Optional[pulumi.Input[str]] = None,
                 iot: Optional[pulumi.Input[str]] = None,
                 kms: Optional[pulumi.Input[str]] = None,
                 kvstore: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 log: Optional[pulumi.Input[str]] = None,
                 market: Optional[pulumi.Input[str]] = None,
                 maxcompute: Optional[pulumi.Input[str]] = None,
                 mhub: Optional[pulumi.Input[str]] = None,
                 mns: Optional[pulumi.Input[str]] = None,
                 mscopensubscription: Optional[pulumi.Input[str]] = None,
                 mse: Optional[pulumi.Input[str]] = None,
                 nas: Optional[pulumi.Input[str]] = None,
                 nlb: Optional[pulumi.Input[str]] = None,
                 oceanbase: Optional[pulumi.Input[str]] = None,
                 ons: Optional[pulumi.Input[str]] = None,
                 onsproxy: Optional[pulumi.Input[str]] = None,
                 oos: Optional[pulumi.Input[str]] = None,
                 opensearch: Optional[pulumi.Input[str]] = None,
                 oss: Optional[pulumi.Input[str]] = None,
                 ots: Optional[pulumi.Input[str]] = None,
                 polardb: Optional[pulumi.Input[str]] = None,
                 privatelink: Optional[pulumi.Input[str]] = None,
                 pvtz: Optional[pulumi.Input[str]] = None,
                 quickbi: Optional[pulumi.Input[str]] = None,
                 quotas: Optional[pulumi.Input[str]] = None,
                 r_kvstore: Optional[pulumi.Input[str]] = None,
                 ram: Optional[pulumi.Input[str]] = None,
                 rds: Optional[pulumi.Input[str]] = None,
                 redisa: Optional[pulumi.Input[str]] = None,
                 resourcemanager: Optional[pulumi.Input[str]] = None,
                 ressharing: Optional[pulumi.Input[str]] = None,
                 ros: Optional[pulumi.Input[str]] = None,
                 sas: Optional[pulumi.Input[str]] = None,
                 scdn: Optional[pulumi.Input[str]] = None,
                 sddp: Optional[pulumi.Input[str]] = None,
                 selectdb: Optional[pulumi.Input[str]] = None,
                 serverless: Optional[pulumi.Input[str]] = None,
                 servicemesh: Optional[pulumi.Input[str]] = None,
                 sgw: Optional[pulumi.Input[str]] = None,
                 slb: Optional[pulumi.Input[str]] = None,
                 smartag: Optional[pulumi.Input[str]] = None,
                 srvcatalog: Optional[pulumi.Input[str]] = None,
                 sts: Optional[pulumi.Input[str]] = None,
                 swas: Optional[pulumi.Input[str]] = None,
                 tag: Optional[pulumi.Input[str]] = None,
                 vod: Optional[pulumi.Input[str]] = None,
                 vpc: Optional[pulumi.Input[str]] = None,
                 vpcpeer: Optional[pulumi.Input[str]] = None,
                 vs: Optional[pulumi.Input[str]] = None,
                 waf: Optional[pulumi.Input[str]] = None,
                 waf_openapi: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] acr: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom acr endpoints.
        :param pulumi.Input[str] actiontrail: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Actiontrail endpoints.
        :param pulumi.Input[str] adb: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom AnalyticDB endpoints.
        :param pulumi.Input[str] alb: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom alb endpoints.
        :param pulumi.Input[str] alidfs: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom alidfs endpoints.
        :param pulumi.Input[str] alidns: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom alidns endpoints.
        :param pulumi.Input[str] alikafka: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ALIKAFKA endpoints.
        :param pulumi.Input[str] apigateway: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Api Gateway endpoints.
        :param pulumi.Input[str] arms: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom arms endpoints.
        :param pulumi.Input[str] bastionhost: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom bastionhost endpoints.
        :param pulumi.Input[str] beebot: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom beebot endpoints.
        :param pulumi.Input[str] bpstudio: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom bpstudio endpoints.
        :param pulumi.Input[str] brain_industrial: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom brain_industrial endpoints.
        :param pulumi.Input[str] bssopenapi: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom BSSOPENAPI endpoints.
        :param pulumi.Input[str] cas: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom CAS endpoints.
        :param pulumi.Input[str] cassandra: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cassandra endpoints.
        :param pulumi.Input[str] cbn: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cbn endpoints.
        :param pulumi.Input[str] cbs: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cbs endpoints.
        :param pulumi.Input[str] cddc: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cddc endpoints.
        :param pulumi.Input[str] cdn: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom CDN endpoints.
        :param pulumi.Input[str] cds: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cds endpoints.
        :param pulumi.Input[str] clickhouse: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom clickhouse endpoints.
        :param pulumi.Input[str] cloudauth: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudauth endpoints.
        :param pulumi.Input[str] cloudfirewall: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudfirewall endpoints.
        :param pulumi.Input[str] cloudfw: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudfw endpoints.
        :param pulumi.Input[str] cloudphone: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudphone endpoints.
        :param pulumi.Input[str] cloudsso: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudsso endpoints.
        :param pulumi.Input[str] cms: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Cloud Monitor endpoints.
        :param pulumi.Input[str] computenest: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom computenest endpoints.
        :param pulumi.Input[str] config: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom config endpoints.
        :param pulumi.Input[str] cr: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Container Registry endpoints.
        :param pulumi.Input[str] cs: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Container Service endpoints.
        :param pulumi.Input[str] das: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom das endpoints.
        :param pulumi.Input[str] datahub: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Datahub endpoints.
        :param pulumi.Input[str] dataworkspublic: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dataworkspublic endpoints.
        :param pulumi.Input[str] dbfs: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dbfs endpoints.
        :param pulumi.Input[str] dcdn: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dcdn endpoints.
        :param pulumi.Input[str] ddosbasic: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ddosbasic endpoints.
        :param pulumi.Input[str] ddosbgp: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DDOSBGP endpoints.
        :param pulumi.Input[str] ddoscoo: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DDOSCOO endpoints.
        :param pulumi.Input[str] dds: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom MongoDB endpoints.
        :param pulumi.Input[str] devopsrdc: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom devopsrdc endpoints.
        :param pulumi.Input[str] dg: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dg endpoints.
        :param pulumi.Input[str] dm: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dm endpoints.
        :param pulumi.Input[str] dms_enterprise: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dms_enterprise endpoints.
        :param pulumi.Input[str] dmsenterprise: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dmsenterprise endpoints.
        :param pulumi.Input[str] dns: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DNS endpoints.
        :param pulumi.Input[str] drds: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DRDS endpoints.
        :param pulumi.Input[str] dts: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dts endpoints.
        :param pulumi.Input[str] eais: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eais endpoints.
        :param pulumi.Input[str] ebs: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ebs endpoints.
        :param pulumi.Input[str] eci: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eci endpoints.
        :param pulumi.Input[str] ecs: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ECS endpoints.
        :param pulumi.Input[str] edas: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom edas endpoints.
        :param pulumi.Input[str] edasschedulerx: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom edasschedulerx endpoints.
        :param pulumi.Input[str] edsuser: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom edsuser endpoints.
        :param pulumi.Input[str] eflo: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eflo endpoints.
        :param pulumi.Input[str] ehpc: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ehpc endpoints.
        :param pulumi.Input[str] ehs: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ehs endpoints.
        :param pulumi.Input[str] eipanycast: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eipanycast endpoints.
        :param pulumi.Input[str] elasticsearch: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Elasticsearch endpoints.
        :param pulumi.Input[str] emr: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom EMR endpoints.
        :param pulumi.Input[str] ens: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ens endpoints.
        :param pulumi.Input[str] ess: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Autoscaling endpoints.
        :param pulumi.Input[str] eventbridge: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eventbridge_share endpoints.
        :param pulumi.Input[str] fc: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Function Computing endpoints.
        :param pulumi.Input[str] fnf: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom fnf endpoints.
        :param pulumi.Input[str] ga: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ga endpoints.
        :param pulumi.Input[str] gaplus: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom gaplus endpoints.
        :param pulumi.Input[str] gds: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom gds endpoints.
        :param pulumi.Input[str] gpdb: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom GPDB endpoints.
        :param pulumi.Input[str] gwsecd: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom gwsecd endpoints.
        :param pulumi.Input[str] hbr: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom hbr endpoints.
        :param pulumi.Input[str] hcs_sgw: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom hcs_sgw endpoints.
        :param pulumi.Input[str] hitsdb: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom hitsdb endpoints.
        :param pulumi.Input[str] imm: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom imm endpoints.
        :param pulumi.Input[str] imp: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom imp endpoints.
        :param pulumi.Input[str] ims: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ims endpoints.
        :param pulumi.Input[str] iot: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom iot endpoints.
        :param pulumi.Input[str] kms: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom KMS endpoints.
        :param pulumi.Input[str] kvstore: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom R-KVStore endpoints.
        :param pulumi.Input[str] location: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Location Service endpoints.
        :param pulumi.Input[str] log: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Log Service endpoints.
        :param pulumi.Input[str] market: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Market Place endpoints.
        :param pulumi.Input[str] maxcompute: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom MaxCompute endpoints.
        :param pulumi.Input[str] mhub: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom mhub endpoints.
        :param pulumi.Input[str] mns: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom MNS endpoints.
        :param pulumi.Input[str] mscopensubscription: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom mscopensubscription endpoints.
        :param pulumi.Input[str] mse: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom mse endpoints.
        :param pulumi.Input[str] nas: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom NAS endpoints.
        :param pulumi.Input[str] nlb: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom nlb endpoints.
        :param pulumi.Input[str] oceanbase: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom oceanbase endpoints.
        :param pulumi.Input[str] ons: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ONS endpoints.
        :param pulumi.Input[str] onsproxy: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom onsproxy endpoints.
        :param pulumi.Input[str] oos: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom oos endpoints.
        :param pulumi.Input[str] opensearch: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom opensearch endpoints.
        :param pulumi.Input[str] oss: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom OSS endpoints.
        :param pulumi.Input[str] ots: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Table Store endpoints.
        :param pulumi.Input[str] polardb: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom PolarDB endpoints.
        :param pulumi.Input[str] privatelink: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom privatelink endpoints.
        :param pulumi.Input[str] pvtz: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Private Zone endpoints.
        :param pulumi.Input[str] quickbi: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom quickbi endpoints.
        :param pulumi.Input[str] quotas: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom quotas endpoints.
        :param pulumi.Input[str] r_kvstore: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom r_kvstore endpoints.
        :param pulumi.Input[str] ram: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom RAM endpoints.
        :param pulumi.Input[str] rds: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom RDS endpoints.
        :param pulumi.Input[str] redisa: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom redisa endpoints.
        :param pulumi.Input[str] resourcemanager: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom resourcemanager endpoints.
        :param pulumi.Input[str] ressharing: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom resourcesharing endpoints.
        :param pulumi.Input[str] ros: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ros endpoints.
        :param pulumi.Input[str] sas: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom sas endpoints.
        :param pulumi.Input[str] scdn: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom scdn endpoints.
        :param pulumi.Input[str] sddp: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom sddp endpoints.
        :param pulumi.Input[str] selectdb: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom selectdb endpoints.
        :param pulumi.Input[str] serverless: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom serverless endpoints.
        :param pulumi.Input[str] servicemesh: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom servicemesh endpoints.
        :param pulumi.Input[str] sgw: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom sgw endpoints.
        :param pulumi.Input[str] slb: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom SLB endpoints.
        :param pulumi.Input[str] smartag: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom smartag endpoints.
        :param pulumi.Input[str] srvcatalog: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom srvcatalog endpoints.
        :param pulumi.Input[str] sts: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom STS endpoints.
        :param pulumi.Input[str] swas: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom swas endpoints.
        :param pulumi.Input[str] tag: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom tag endpoints.
        :param pulumi.Input[str] vod: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom vod endpoints.
        :param pulumi.Input[str] vpc: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom VPC and VPN endpoints.
        :param pulumi.Input[str] vpcpeer: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom vpcpeer endpoints.
        :param pulumi.Input[str] vs: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom vs endpoints.
        :param pulumi.Input[str] waf: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom waf endpoints.
        :param pulumi.Input[str] waf_openapi: Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom waf_openapi endpoints.
        """
        if acr is not None:
            pulumi.set(__self__, "acr", acr)
        if actiontrail is not None:
            pulumi.set(__self__, "actiontrail", actiontrail)
        if adb is not None:
            pulumi.set(__self__, "adb", adb)
        if alb is not None:
            pulumi.set(__self__, "alb", alb)
        if alidfs is not None:
            pulumi.set(__self__, "alidfs", alidfs)
        if alidns is not None:
            pulumi.set(__self__, "alidns", alidns)
        if alikafka is not None:
            pulumi.set(__self__, "alikafka", alikafka)
        if apigateway is not None:
            pulumi.set(__self__, "apigateway", apigateway)
        if arms is not None:
            pulumi.set(__self__, "arms", arms)
        if bastionhost is not None:
            pulumi.set(__self__, "bastionhost", bastionhost)
        if beebot is not None:
            pulumi.set(__self__, "beebot", beebot)
        if bpstudio is not None:
            pulumi.set(__self__, "bpstudio", bpstudio)
        if brain_industrial is not None:
            pulumi.set(__self__, "brain_industrial", brain_industrial)
        if bssopenapi is not None:
            pulumi.set(__self__, "bssopenapi", bssopenapi)
        if cas is not None:
            pulumi.set(__self__, "cas", cas)
        if cassandra is not None:
            pulumi.set(__self__, "cassandra", cassandra)
        if cbn is not None:
            pulumi.set(__self__, "cbn", cbn)
        if cbs is not None:
            pulumi.set(__self__, "cbs", cbs)
        if cddc is not None:
            pulumi.set(__self__, "cddc", cddc)
        if cdn is not None:
            pulumi.set(__self__, "cdn", cdn)
        if cds is not None:
            pulumi.set(__self__, "cds", cds)
        if clickhouse is not None:
            pulumi.set(__self__, "clickhouse", clickhouse)
        if cloudauth is not None:
            pulumi.set(__self__, "cloudauth", cloudauth)
        if cloudfirewall is not None:
            pulumi.set(__self__, "cloudfirewall", cloudfirewall)
        if cloudfw is not None:
            pulumi.set(__self__, "cloudfw", cloudfw)
        if cloudphone is not None:
            pulumi.set(__self__, "cloudphone", cloudphone)
        if cloudsso is not None:
            pulumi.set(__self__, "cloudsso", cloudsso)
        if cms is not None:
            pulumi.set(__self__, "cms", cms)
        if computenest is not None:
            pulumi.set(__self__, "computenest", computenest)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if cr is not None:
            pulumi.set(__self__, "cr", cr)
        if cs is not None:
            pulumi.set(__self__, "cs", cs)
        if das is not None:
            pulumi.set(__self__, "das", das)
        if datahub is not None:
            pulumi.set(__self__, "datahub", datahub)
        if dataworkspublic is not None:
            pulumi.set(__self__, "dataworkspublic", dataworkspublic)
        if dbfs is not None:
            pulumi.set(__self__, "dbfs", dbfs)
        if dcdn is not None:
            pulumi.set(__self__, "dcdn", dcdn)
        if ddosbasic is not None:
            pulumi.set(__self__, "ddosbasic", ddosbasic)
        if ddosbgp is not None:
            pulumi.set(__self__, "ddosbgp", ddosbgp)
        if ddoscoo is not None:
            pulumi.set(__self__, "ddoscoo", ddoscoo)
        if dds is not None:
            pulumi.set(__self__, "dds", dds)
        if devopsrdc is not None:
            pulumi.set(__self__, "devopsrdc", devopsrdc)
        if dg is not None:
            pulumi.set(__self__, "dg", dg)
        if dm is not None:
            pulumi.set(__self__, "dm", dm)
        if dms_enterprise is not None:
            pulumi.set(__self__, "dms_enterprise", dms_enterprise)
        if dmsenterprise is not None:
            pulumi.set(__self__, "dmsenterprise", dmsenterprise)
        if dns is not None:
            pulumi.set(__self__, "dns", dns)
        if drds is not None:
            pulumi.set(__self__, "drds", drds)
        if dts is not None:
            pulumi.set(__self__, "dts", dts)
        if dysms is not None:
            pulumi.set(__self__, "dysms", dysms)
        if eais is not None:
            pulumi.set(__self__, "eais", eais)
        if ebs is not None:
            pulumi.set(__self__, "ebs", ebs)
        if eci is not None:
            pulumi.set(__self__, "eci", eci)
        if ecs is not None:
            pulumi.set(__self__, "ecs", ecs)
        if edas is not None:
            pulumi.set(__self__, "edas", edas)
        if edasschedulerx is not None:
            pulumi.set(__self__, "edasschedulerx", edasschedulerx)
        if edsuser is not None:
            pulumi.set(__self__, "edsuser", edsuser)
        if eflo is not None:
            pulumi.set(__self__, "eflo", eflo)
        if ehpc is not None:
            pulumi.set(__self__, "ehpc", ehpc)
        if ehs is not None:
            pulumi.set(__self__, "ehs", ehs)
        if eipanycast is not None:
            pulumi.set(__self__, "eipanycast", eipanycast)
        if elasticsearch is not None:
            pulumi.set(__self__, "elasticsearch", elasticsearch)
        if emr is not None:
            pulumi.set(__self__, "emr", emr)
        if ens is not None:
            pulumi.set(__self__, "ens", ens)
        if ess is not None:
            pulumi.set(__self__, "ess", ess)
        if eventbridge is not None:
            pulumi.set(__self__, "eventbridge", eventbridge)
        if fc is not None:
            pulumi.set(__self__, "fc", fc)
        if fnf is not None:
            pulumi.set(__self__, "fnf", fnf)
        if ga is not None:
            pulumi.set(__self__, "ga", ga)
        if gaplus is not None:
            pulumi.set(__self__, "gaplus", gaplus)
        if gds is not None:
            pulumi.set(__self__, "gds", gds)
        if gpdb is not None:
            pulumi.set(__self__, "gpdb", gpdb)
        if gwsecd is not None:
            pulumi.set(__self__, "gwsecd", gwsecd)
        if hbr is not None:
            pulumi.set(__self__, "hbr", hbr)
        if hcs_sgw is not None:
            pulumi.set(__self__, "hcs_sgw", hcs_sgw)
        if hitsdb is not None:
            pulumi.set(__self__, "hitsdb", hitsdb)
        if imm is not None:
            pulumi.set(__self__, "imm", imm)
        if imp is not None:
            pulumi.set(__self__, "imp", imp)
        if ims is not None:
            pulumi.set(__self__, "ims", ims)
        if iot is not None:
            pulumi.set(__self__, "iot", iot)
        if kms is not None:
            pulumi.set(__self__, "kms", kms)
        if kvstore is not None:
            pulumi.set(__self__, "kvstore", kvstore)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if log is not None:
            pulumi.set(__self__, "log", log)
        if market is not None:
            pulumi.set(__self__, "market", market)
        if maxcompute is not None:
            pulumi.set(__self__, "maxcompute", maxcompute)
        if mhub is not None:
            pulumi.set(__self__, "mhub", mhub)
        if mns is not None:
            pulumi.set(__self__, "mns", mns)
        if mscopensubscription is not None:
            pulumi.set(__self__, "mscopensubscription", mscopensubscription)
        if mse is not None:
            pulumi.set(__self__, "mse", mse)
        if nas is not None:
            pulumi.set(__self__, "nas", nas)
        if nlb is not None:
            pulumi.set(__self__, "nlb", nlb)
        if oceanbase is not None:
            pulumi.set(__self__, "oceanbase", oceanbase)
        if ons is not None:
            pulumi.set(__self__, "ons", ons)
        if onsproxy is not None:
            pulumi.set(__self__, "onsproxy", onsproxy)
        if oos is not None:
            pulumi.set(__self__, "oos", oos)
        if opensearch is not None:
            pulumi.set(__self__, "opensearch", opensearch)
        if oss is not None:
            pulumi.set(__self__, "oss", oss)
        if ots is not None:
            pulumi.set(__self__, "ots", ots)
        if polardb is not None:
            pulumi.set(__self__, "polardb", polardb)
        if privatelink is not None:
            pulumi.set(__self__, "privatelink", privatelink)
        if pvtz is not None:
            pulumi.set(__self__, "pvtz", pvtz)
        if quickbi is not None:
            pulumi.set(__self__, "quickbi", quickbi)
        if quotas is not None:
            pulumi.set(__self__, "quotas", quotas)
        if r_kvstore is not None:
            pulumi.set(__self__, "r_kvstore", r_kvstore)
        if ram is not None:
            pulumi.set(__self__, "ram", ram)
        if rds is not None:
            pulumi.set(__self__, "rds", rds)
        if redisa is not None:
            pulumi.set(__self__, "redisa", redisa)
        if resourcemanager is not None:
            pulumi.set(__self__, "resourcemanager", resourcemanager)
        if ressharing is not None:
            pulumi.set(__self__, "ressharing", ressharing)
        if ros is not None:
            pulumi.set(__self__, "ros", ros)
        if sas is not None:
            pulumi.set(__self__, "sas", sas)
        if scdn is not None:
            pulumi.set(__self__, "scdn", scdn)
        if sddp is not None:
            pulumi.set(__self__, "sddp", sddp)
        if selectdb is not None:
            pulumi.set(__self__, "selectdb", selectdb)
        if serverless is not None:
            pulumi.set(__self__, "serverless", serverless)
        if servicemesh is not None:
            pulumi.set(__self__, "servicemesh", servicemesh)
        if sgw is not None:
            pulumi.set(__self__, "sgw", sgw)
        if slb is not None:
            pulumi.set(__self__, "slb", slb)
        if smartag is not None:
            pulumi.set(__self__, "smartag", smartag)
        if srvcatalog is not None:
            pulumi.set(__self__, "srvcatalog", srvcatalog)
        if sts is not None:
            pulumi.set(__self__, "sts", sts)
        if swas is not None:
            pulumi.set(__self__, "swas", swas)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)
        if vod is not None:
            pulumi.set(__self__, "vod", vod)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)
        if vpcpeer is not None:
            pulumi.set(__self__, "vpcpeer", vpcpeer)
        if vs is not None:
            pulumi.set(__self__, "vs", vs)
        if waf is not None:
            pulumi.set(__self__, "waf", waf)
        if waf_openapi is not None:
            pulumi.set(__self__, "waf_openapi", waf_openapi)

    @property
    @pulumi.getter
    def acr(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom acr endpoints.
        """
        return pulumi.get(self, "acr")

    @acr.setter
    def acr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "acr", value)

    @property
    @pulumi.getter
    def actiontrail(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Actiontrail endpoints.
        """
        return pulumi.get(self, "actiontrail")

    @actiontrail.setter
    def actiontrail(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "actiontrail", value)

    @property
    @pulumi.getter
    def adb(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom AnalyticDB endpoints.
        """
        return pulumi.get(self, "adb")

    @adb.setter
    def adb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "adb", value)

    @property
    @pulumi.getter
    def alb(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom alb endpoints.
        """
        return pulumi.get(self, "alb")

    @alb.setter
    def alb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alb", value)

    @property
    @pulumi.getter
    def alidfs(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom alidfs endpoints.
        """
        return pulumi.get(self, "alidfs")

    @alidfs.setter
    def alidfs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alidfs", value)

    @property
    @pulumi.getter
    def alidns(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom alidns endpoints.
        """
        return pulumi.get(self, "alidns")

    @alidns.setter
    def alidns(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alidns", value)

    @property
    @pulumi.getter
    def alikafka(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ALIKAFKA endpoints.
        """
        return pulumi.get(self, "alikafka")

    @alikafka.setter
    def alikafka(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alikafka", value)

    @property
    @pulumi.getter
    def apigateway(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Api Gateway endpoints.
        """
        return pulumi.get(self, "apigateway")

    @apigateway.setter
    def apigateway(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "apigateway", value)

    @property
    @pulumi.getter
    def arms(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom arms endpoints.
        """
        return pulumi.get(self, "arms")

    @arms.setter
    def arms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arms", value)

    @property
    @pulumi.getter
    def bastionhost(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom bastionhost endpoints.
        """
        return pulumi.get(self, "bastionhost")

    @bastionhost.setter
    def bastionhost(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bastionhost", value)

    @property
    @pulumi.getter
    def beebot(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom beebot endpoints.
        """
        return pulumi.get(self, "beebot")

    @beebot.setter
    def beebot(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "beebot", value)

    @property
    @pulumi.getter
    def bpstudio(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom bpstudio endpoints.
        """
        return pulumi.get(self, "bpstudio")

    @bpstudio.setter
    def bpstudio(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bpstudio", value)

    @property
    @pulumi.getter(name="brainIndustrial")
    def brain_industrial(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom brain_industrial endpoints.
        """
        return pulumi.get(self, "brain_industrial")

    @brain_industrial.setter
    def brain_industrial(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "brain_industrial", value)

    @property
    @pulumi.getter
    def bssopenapi(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom BSSOPENAPI endpoints.
        """
        return pulumi.get(self, "bssopenapi")

    @bssopenapi.setter
    def bssopenapi(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bssopenapi", value)

    @property
    @pulumi.getter
    def cas(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom CAS endpoints.
        """
        return pulumi.get(self, "cas")

    @cas.setter
    def cas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cas", value)

    @property
    @pulumi.getter
    def cassandra(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cassandra endpoints.
        """
        return pulumi.get(self, "cassandra")

    @cassandra.setter
    def cassandra(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cassandra", value)

    @property
    @pulumi.getter
    def cbn(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cbn endpoints.
        """
        return pulumi.get(self, "cbn")

    @cbn.setter
    def cbn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cbn", value)

    @property
    @pulumi.getter
    def cbs(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cbs endpoints.
        """
        return pulumi.get(self, "cbs")

    @cbs.setter
    def cbs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cbs", value)

    @property
    @pulumi.getter
    def cddc(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cddc endpoints.
        """
        return pulumi.get(self, "cddc")

    @cddc.setter
    def cddc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cddc", value)

    @property
    @pulumi.getter
    def cdn(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom CDN endpoints.
        """
        return pulumi.get(self, "cdn")

    @cdn.setter
    def cdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cdn", value)

    @property
    @pulumi.getter
    def cds(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cds endpoints.
        """
        return pulumi.get(self, "cds")

    @cds.setter
    def cds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cds", value)

    @property
    @pulumi.getter
    def clickhouse(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom clickhouse endpoints.
        """
        return pulumi.get(self, "clickhouse")

    @clickhouse.setter
    def clickhouse(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "clickhouse", value)

    @property
    @pulumi.getter
    def cloudauth(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudauth endpoints.
        """
        return pulumi.get(self, "cloudauth")

    @cloudauth.setter
    def cloudauth(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudauth", value)

    @property
    @pulumi.getter
    def cloudfirewall(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudfirewall endpoints.
        """
        return pulumi.get(self, "cloudfirewall")

    @cloudfirewall.setter
    def cloudfirewall(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudfirewall", value)

    @property
    @pulumi.getter
    def cloudfw(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudfw endpoints.
        """
        return pulumi.get(self, "cloudfw")

    @cloudfw.setter
    def cloudfw(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudfw", value)

    @property
    @pulumi.getter
    def cloudphone(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudphone endpoints.
        """
        return pulumi.get(self, "cloudphone")

    @cloudphone.setter
    def cloudphone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudphone", value)

    @property
    @pulumi.getter
    def cloudsso(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom cloudsso endpoints.
        """
        return pulumi.get(self, "cloudsso")

    @cloudsso.setter
    def cloudsso(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudsso", value)

    @property
    @pulumi.getter
    def cms(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Cloud Monitor endpoints.
        """
        return pulumi.get(self, "cms")

    @cms.setter
    def cms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cms", value)

    @property
    @pulumi.getter
    def computenest(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom computenest endpoints.
        """
        return pulumi.get(self, "computenest")

    @computenest.setter
    def computenest(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "computenest", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom config endpoints.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def cr(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Container Registry endpoints.
        """
        return pulumi.get(self, "cr")

    @cr.setter
    def cr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cr", value)

    @property
    @pulumi.getter
    def cs(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Container Service endpoints.
        """
        return pulumi.get(self, "cs")

    @cs.setter
    def cs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cs", value)

    @property
    @pulumi.getter
    def das(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom das endpoints.
        """
        return pulumi.get(self, "das")

    @das.setter
    def das(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "das", value)

    @property
    @pulumi.getter
    def datahub(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Datahub endpoints.
        """
        return pulumi.get(self, "datahub")

    @datahub.setter
    def datahub(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "datahub", value)

    @property
    @pulumi.getter
    def dataworkspublic(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dataworkspublic endpoints.
        """
        return pulumi.get(self, "dataworkspublic")

    @dataworkspublic.setter
    def dataworkspublic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dataworkspublic", value)

    @property
    @pulumi.getter
    def dbfs(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dbfs endpoints.
        """
        return pulumi.get(self, "dbfs")

    @dbfs.setter
    def dbfs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dbfs", value)

    @property
    @pulumi.getter
    def dcdn(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dcdn endpoints.
        """
        return pulumi.get(self, "dcdn")

    @dcdn.setter
    def dcdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dcdn", value)

    @property
    @pulumi.getter
    def ddosbasic(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ddosbasic endpoints.
        """
        return pulumi.get(self, "ddosbasic")

    @ddosbasic.setter
    def ddosbasic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ddosbasic", value)

    @property
    @pulumi.getter
    def ddosbgp(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DDOSBGP endpoints.
        """
        return pulumi.get(self, "ddosbgp")

    @ddosbgp.setter
    def ddosbgp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ddosbgp", value)

    @property
    @pulumi.getter
    def ddoscoo(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DDOSCOO endpoints.
        """
        return pulumi.get(self, "ddoscoo")

    @ddoscoo.setter
    def ddoscoo(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ddoscoo", value)

    @property
    @pulumi.getter
    def dds(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom MongoDB endpoints.
        """
        return pulumi.get(self, "dds")

    @dds.setter
    def dds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dds", value)

    @property
    @pulumi.getter
    def devopsrdc(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom devopsrdc endpoints.
        """
        return pulumi.get(self, "devopsrdc")

    @devopsrdc.setter
    def devopsrdc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "devopsrdc", value)

    @property
    @pulumi.getter
    def dg(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dg endpoints.
        """
        return pulumi.get(self, "dg")

    @dg.setter
    def dg(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dg", value)

    @property
    @pulumi.getter
    def dm(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dm endpoints.
        """
        return pulumi.get(self, "dm")

    @dm.setter
    def dm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dm", value)

    @property
    @pulumi.getter(name="dmsEnterprise")
    def dms_enterprise(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dms_enterprise endpoints.
        """
        return pulumi.get(self, "dms_enterprise")

    @dms_enterprise.setter
    def dms_enterprise(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dms_enterprise", value)

    @property
    @pulumi.getter
    def dmsenterprise(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dmsenterprise endpoints.
        """
        return pulumi.get(self, "dmsenterprise")

    @dmsenterprise.setter
    def dmsenterprise(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dmsenterprise", value)

    @property
    @pulumi.getter
    def dns(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DNS endpoints.
        """
        return pulumi.get(self, "dns")

    @dns.setter
    def dns(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dns", value)

    @property
    @pulumi.getter
    def drds(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom DRDS endpoints.
        """
        return pulumi.get(self, "drds")

    @drds.setter
    def drds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "drds", value)

    @property
    @pulumi.getter
    def dts(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom dts endpoints.
        """
        return pulumi.get(self, "dts")

    @dts.setter
    def dts(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dts", value)

    @property
    @pulumi.getter
    def dysms(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dysms")

    @dysms.setter
    def dysms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dysms", value)

    @property
    @pulumi.getter
    def eais(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eais endpoints.
        """
        return pulumi.get(self, "eais")

    @eais.setter
    def eais(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eais", value)

    @property
    @pulumi.getter
    def ebs(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ebs endpoints.
        """
        return pulumi.get(self, "ebs")

    @ebs.setter
    def ebs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ebs", value)

    @property
    @pulumi.getter
    def eci(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eci endpoints.
        """
        return pulumi.get(self, "eci")

    @eci.setter
    def eci(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eci", value)

    @property
    @pulumi.getter
    def ecs(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ECS endpoints.
        """
        return pulumi.get(self, "ecs")

    @ecs.setter
    def ecs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ecs", value)

    @property
    @pulumi.getter
    def edas(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom edas endpoints.
        """
        return pulumi.get(self, "edas")

    @edas.setter
    def edas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "edas", value)

    @property
    @pulumi.getter
    def edasschedulerx(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom edasschedulerx endpoints.
        """
        return pulumi.get(self, "edasschedulerx")

    @edasschedulerx.setter
    def edasschedulerx(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "edasschedulerx", value)

    @property
    @pulumi.getter
    def edsuser(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom edsuser endpoints.
        """
        return pulumi.get(self, "edsuser")

    @edsuser.setter
    def edsuser(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "edsuser", value)

    @property
    @pulumi.getter
    def eflo(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eflo endpoints.
        """
        return pulumi.get(self, "eflo")

    @eflo.setter
    def eflo(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eflo", value)

    @property
    @pulumi.getter
    def ehpc(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ehpc endpoints.
        """
        return pulumi.get(self, "ehpc")

    @ehpc.setter
    def ehpc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ehpc", value)

    @property
    @pulumi.getter
    def ehs(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ehs endpoints.
        """
        return pulumi.get(self, "ehs")

    @ehs.setter
    def ehs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ehs", value)

    @property
    @pulumi.getter
    def eipanycast(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eipanycast endpoints.
        """
        return pulumi.get(self, "eipanycast")

    @eipanycast.setter
    def eipanycast(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eipanycast", value)

    @property
    @pulumi.getter
    def elasticsearch(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Elasticsearch endpoints.
        """
        return pulumi.get(self, "elasticsearch")

    @elasticsearch.setter
    def elasticsearch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "elasticsearch", value)

    @property
    @pulumi.getter
    def emr(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom EMR endpoints.
        """
        return pulumi.get(self, "emr")

    @emr.setter
    def emr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "emr", value)

    @property
    @pulumi.getter
    def ens(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ens endpoints.
        """
        return pulumi.get(self, "ens")

    @ens.setter
    def ens(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ens", value)

    @property
    @pulumi.getter
    def ess(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Autoscaling endpoints.
        """
        return pulumi.get(self, "ess")

    @ess.setter
    def ess(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ess", value)

    @property
    @pulumi.getter
    def eventbridge(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom eventbridge_share endpoints.
        """
        return pulumi.get(self, "eventbridge")

    @eventbridge.setter
    def eventbridge(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eventbridge", value)

    @property
    @pulumi.getter
    def fc(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Function Computing endpoints.
        """
        return pulumi.get(self, "fc")

    @fc.setter
    def fc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fc", value)

    @property
    @pulumi.getter
    def fnf(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom fnf endpoints.
        """
        return pulumi.get(self, "fnf")

    @fnf.setter
    def fnf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fnf", value)

    @property
    @pulumi.getter
    def ga(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ga endpoints.
        """
        return pulumi.get(self, "ga")

    @ga.setter
    def ga(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ga", value)

    @property
    @pulumi.getter
    def gaplus(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom gaplus endpoints.
        """
        return pulumi.get(self, "gaplus")

    @gaplus.setter
    def gaplus(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gaplus", value)

    @property
    @pulumi.getter
    def gds(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom gds endpoints.
        """
        return pulumi.get(self, "gds")

    @gds.setter
    def gds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gds", value)

    @property
    @pulumi.getter
    def gpdb(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom GPDB endpoints.
        """
        return pulumi.get(self, "gpdb")

    @gpdb.setter
    def gpdb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gpdb", value)

    @property
    @pulumi.getter
    def gwsecd(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom gwsecd endpoints.
        """
        return pulumi.get(self, "gwsecd")

    @gwsecd.setter
    def gwsecd(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gwsecd", value)

    @property
    @pulumi.getter
    def hbr(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom hbr endpoints.
        """
        return pulumi.get(self, "hbr")

    @hbr.setter
    def hbr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hbr", value)

    @property
    @pulumi.getter(name="hcsSgw")
    def hcs_sgw(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom hcs_sgw endpoints.
        """
        return pulumi.get(self, "hcs_sgw")

    @hcs_sgw.setter
    def hcs_sgw(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hcs_sgw", value)

    @property
    @pulumi.getter
    def hitsdb(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom hitsdb endpoints.
        """
        return pulumi.get(self, "hitsdb")

    @hitsdb.setter
    def hitsdb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hitsdb", value)

    @property
    @pulumi.getter
    def imm(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom imm endpoints.
        """
        return pulumi.get(self, "imm")

    @imm.setter
    def imm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "imm", value)

    @property
    @pulumi.getter
    def imp(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom imp endpoints.
        """
        return pulumi.get(self, "imp")

    @imp.setter
    def imp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "imp", value)

    @property
    @pulumi.getter
    def ims(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ims endpoints.
        """
        return pulumi.get(self, "ims")

    @ims.setter
    def ims(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ims", value)

    @property
    @pulumi.getter
    def iot(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom iot endpoints.
        """
        return pulumi.get(self, "iot")

    @iot.setter
    def iot(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "iot", value)

    @property
    @pulumi.getter
    def kms(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom KMS endpoints.
        """
        return pulumi.get(self, "kms")

    @kms.setter
    def kms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms", value)

    @property
    @pulumi.getter
    def kvstore(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom R-KVStore endpoints.
        """
        return pulumi.get(self, "kvstore")

    @kvstore.setter
    def kvstore(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kvstore", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Location Service endpoints.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def log(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Log Service endpoints.
        """
        return pulumi.get(self, "log")

    @log.setter
    def log(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log", value)

    @property
    @pulumi.getter
    def market(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Market Place endpoints.
        """
        return pulumi.get(self, "market")

    @market.setter
    def market(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "market", value)

    @property
    @pulumi.getter
    def maxcompute(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom MaxCompute endpoints.
        """
        return pulumi.get(self, "maxcompute")

    @maxcompute.setter
    def maxcompute(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "maxcompute", value)

    @property
    @pulumi.getter
    def mhub(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom mhub endpoints.
        """
        return pulumi.get(self, "mhub")

    @mhub.setter
    def mhub(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mhub", value)

    @property
    @pulumi.getter
    def mns(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom MNS endpoints.
        """
        return pulumi.get(self, "mns")

    @mns.setter
    def mns(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mns", value)

    @property
    @pulumi.getter
    def mscopensubscription(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom mscopensubscription endpoints.
        """
        return pulumi.get(self, "mscopensubscription")

    @mscopensubscription.setter
    def mscopensubscription(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mscopensubscription", value)

    @property
    @pulumi.getter
    def mse(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom mse endpoints.
        """
        return pulumi.get(self, "mse")

    @mse.setter
    def mse(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mse", value)

    @property
    @pulumi.getter
    def nas(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom NAS endpoints.
        """
        return pulumi.get(self, "nas")

    @nas.setter
    def nas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nas", value)

    @property
    @pulumi.getter
    def nlb(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom nlb endpoints.
        """
        return pulumi.get(self, "nlb")

    @nlb.setter
    def nlb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nlb", value)

    @property
    @pulumi.getter
    def oceanbase(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom oceanbase endpoints.
        """
        return pulumi.get(self, "oceanbase")

    @oceanbase.setter
    def oceanbase(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oceanbase", value)

    @property
    @pulumi.getter
    def ons(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ONS endpoints.
        """
        return pulumi.get(self, "ons")

    @ons.setter
    def ons(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ons", value)

    @property
    @pulumi.getter
    def onsproxy(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom onsproxy endpoints.
        """
        return pulumi.get(self, "onsproxy")

    @onsproxy.setter
    def onsproxy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "onsproxy", value)

    @property
    @pulumi.getter
    def oos(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom oos endpoints.
        """
        return pulumi.get(self, "oos")

    @oos.setter
    def oos(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oos", value)

    @property
    @pulumi.getter
    def opensearch(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom opensearch endpoints.
        """
        return pulumi.get(self, "opensearch")

    @opensearch.setter
    def opensearch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "opensearch", value)

    @property
    @pulumi.getter
    def oss(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom OSS endpoints.
        """
        return pulumi.get(self, "oss")

    @oss.setter
    def oss(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oss", value)

    @property
    @pulumi.getter
    def ots(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Table Store endpoints.
        """
        return pulumi.get(self, "ots")

    @ots.setter
    def ots(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ots", value)

    @property
    @pulumi.getter
    def polardb(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom PolarDB endpoints.
        """
        return pulumi.get(self, "polardb")

    @polardb.setter
    def polardb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "polardb", value)

    @property
    @pulumi.getter
    def privatelink(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom privatelink endpoints.
        """
        return pulumi.get(self, "privatelink")

    @privatelink.setter
    def privatelink(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "privatelink", value)

    @property
    @pulumi.getter
    def pvtz(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom Private Zone endpoints.
        """
        return pulumi.get(self, "pvtz")

    @pvtz.setter
    def pvtz(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pvtz", value)

    @property
    @pulumi.getter
    def quickbi(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom quickbi endpoints.
        """
        return pulumi.get(self, "quickbi")

    @quickbi.setter
    def quickbi(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quickbi", value)

    @property
    @pulumi.getter
    def quotas(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom quotas endpoints.
        """
        return pulumi.get(self, "quotas")

    @quotas.setter
    def quotas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quotas", value)

    @property
    @pulumi.getter(name="rKvstore")
    def r_kvstore(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom r_kvstore endpoints.
        """
        return pulumi.get(self, "r_kvstore")

    @r_kvstore.setter
    def r_kvstore(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "r_kvstore", value)

    @property
    @pulumi.getter
    def ram(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom RAM endpoints.
        """
        return pulumi.get(self, "ram")

    @ram.setter
    def ram(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ram", value)

    @property
    @pulumi.getter
    def rds(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom RDS endpoints.
        """
        return pulumi.get(self, "rds")

    @rds.setter
    def rds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rds", value)

    @property
    @pulumi.getter
    def redisa(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom redisa endpoints.
        """
        return pulumi.get(self, "redisa")

    @redisa.setter
    def redisa(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "redisa", value)

    @property
    @pulumi.getter
    def resourcemanager(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom resourcemanager endpoints.
        """
        return pulumi.get(self, "resourcemanager")

    @resourcemanager.setter
    def resourcemanager(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resourcemanager", value)

    @property
    @pulumi.getter
    def ressharing(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom resourcesharing endpoints.
        """
        return pulumi.get(self, "ressharing")

    @ressharing.setter
    def ressharing(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ressharing", value)

    @property
    @pulumi.getter
    def ros(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom ros endpoints.
        """
        return pulumi.get(self, "ros")

    @ros.setter
    def ros(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ros", value)

    @property
    @pulumi.getter
    def sas(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom sas endpoints.
        """
        return pulumi.get(self, "sas")

    @sas.setter
    def sas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas", value)

    @property
    @pulumi.getter
    def scdn(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom scdn endpoints.
        """
        return pulumi.get(self, "scdn")

    @scdn.setter
    def scdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scdn", value)

    @property
    @pulumi.getter
    def sddp(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom sddp endpoints.
        """
        return pulumi.get(self, "sddp")

    @sddp.setter
    def sddp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sddp", value)

    @property
    @pulumi.getter
    def selectdb(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom selectdb endpoints.
        """
        return pulumi.get(self, "selectdb")

    @selectdb.setter
    def selectdb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "selectdb", value)

    @property
    @pulumi.getter
    def serverless(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom serverless endpoints.
        """
        return pulumi.get(self, "serverless")

    @serverless.setter
    def serverless(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "serverless", value)

    @property
    @pulumi.getter
    def servicemesh(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom servicemesh endpoints.
        """
        return pulumi.get(self, "servicemesh")

    @servicemesh.setter
    def servicemesh(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "servicemesh", value)

    @property
    @pulumi.getter
    def sgw(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom sgw endpoints.
        """
        return pulumi.get(self, "sgw")

    @sgw.setter
    def sgw(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sgw", value)

    @property
    @pulumi.getter
    def slb(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom SLB endpoints.
        """
        return pulumi.get(self, "slb")

    @slb.setter
    def slb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slb", value)

    @property
    @pulumi.getter
    def smartag(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom smartag endpoints.
        """
        return pulumi.get(self, "smartag")

    @smartag.setter
    def smartag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "smartag", value)

    @property
    @pulumi.getter
    def srvcatalog(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom srvcatalog endpoints.
        """
        return pulumi.get(self, "srvcatalog")

    @srvcatalog.setter
    def srvcatalog(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "srvcatalog", value)

    @property
    @pulumi.getter
    def sts(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom STS endpoints.
        """
        return pulumi.get(self, "sts")

    @sts.setter
    def sts(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sts", value)

    @property
    @pulumi.getter
    def swas(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom swas endpoints.
        """
        return pulumi.get(self, "swas")

    @swas.setter
    def swas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "swas", value)

    @property
    @pulumi.getter
    def tag(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom tag endpoints.
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tag", value)

    @property
    @pulumi.getter
    def vod(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom vod endpoints.
        """
        return pulumi.get(self, "vod")

    @vod.setter
    def vod(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vod", value)

    @property
    @pulumi.getter
    def vpc(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom VPC and VPN endpoints.
        """
        return pulumi.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc", value)

    @property
    @pulumi.getter
    def vpcpeer(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom vpcpeer endpoints.
        """
        return pulumi.get(self, "vpcpeer")

    @vpcpeer.setter
    def vpcpeer(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpcpeer", value)

    @property
    @pulumi.getter
    def vs(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom vs endpoints.
        """
        return pulumi.get(self, "vs")

    @vs.setter
    def vs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vs", value)

    @property
    @pulumi.getter
    def waf(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom waf endpoints.
        """
        return pulumi.get(self, "waf")

    @waf.setter
    def waf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "waf", value)

    @property
    @pulumi.getter(name="wafOpenapi")
    def waf_openapi(self) -> Optional[pulumi.Input[str]]:
        """
        Use this to override the default endpoint URL constructed from the `region`. It's typically used to connect to custom waf_openapi endpoints.
        """
        return pulumi.get(self, "waf_openapi")

    @waf_openapi.setter
    def waf_openapi(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "waf_openapi", value)


if not MYPY:
    class ProviderSignVersionArgsDict(TypedDict):
        oss: NotRequired[pulumi.Input[str]]
        sls: NotRequired[pulumi.Input[str]]
elif False:
    ProviderSignVersionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ProviderSignVersionArgs:
    def __init__(__self__, *,
                 oss: Optional[pulumi.Input[str]] = None,
                 sls: Optional[pulumi.Input[str]] = None):
        if oss is not None:
            pulumi.set(__self__, "oss", oss)
        if sls is not None:
            pulumi.set(__self__, "sls", sls)

    @property
    @pulumi.getter
    def oss(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "oss")

    @oss.setter
    def oss(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oss", value)

    @property
    @pulumi.getter
    def sls(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "sls")

    @sls.setter
    def sls(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sls", value)


